==> maven-plugin-descriptor-2.0-sources.jar: org/apache/maven/plugin/lifecycle/Lifecycle.java <==
/*
 * $Id$
 */

package org.apache.maven.plugin.lifecycle;

  //---------------------------------/
 //- Imported classes and packages -/
//---------------------------------/

import java.util.*;
import java.util.List;

/**
 * Class Lifecycle.
 * 
 * @version $Revision$ $Date$
 */
public class Lifecycle implements java.io.Serializable {


      //--------------------------/
     //- Class/Member Variables -/
    //--------------------------/

    /**
     * Field id
     */
    private String id;

    /**
     * Field phases
     */
    private java.util.List phases;


      //-----------/
     //- Methods -/
    //-----------/

    /**
     * Method addPhase
     * 
     * @param phase
     */
    public void addPhase(Phase phase)
    {
        getPhases().add( phase );
    } //-- void addPhase(Phase) 

    /**
     * Method getId
     */
    public String getId()
    {
        return this.id;
    } //-- String getId() 

    /**
     * Method getPhases
     */
    public java.util.List getPhases()
    {
        if ( this.phases == null )
        {
            this.phases = new java.util.ArrayList();
        }
        
        return this.phases;
    } //-- java.util.List getPhases() 

    /**
     * Method removePhase
     * 
     * @param phase
     */
    public void removePhase(Phase phase)
    {
        getPhases().remove( phase );
    } //-- void removePhase(Phase) 

    /**
     * Method setId
     * 
     * @param id
     */
    public void setId(String id)
    {
        this.id = id;
    } //-- void setId(String) 

    /**
     * Method setPhases
     * 
     * @param phases
     */
    public void setPhases(java.util.List phases)
    {
        this.phases = phases;
    } //-- void setPhases(java.util.List) 

}

==> maven-plugin-descriptor-2.0.7-sources.jar: org/apache/maven/plugin/lifecycle/Lifecycle.java <==
/*
 * $Id$
 */

package org.apache.maven.plugin.lifecycle;

/**
 * 
 *         A custom lifecycle mapping definition.
 *       
 * 
 * @version $Revision$ $Date$
 */
public class Lifecycle implements java.io.Serializable {


      //--------------------------/
     //- Class/Member Variables -/
    //--------------------------/

    /**
     * Field id
     */
    private String id;

    /**
     * Field phases
     */
    private java.util.List phases;


      //-----------/
     //- Methods -/
    //-----------/

    /**
     * Method addPhase
     * 
     * @param phase
     */
    public void addPhase(Phase phase)
    {
        getPhases().add( phase );
    } //-- void addPhase(Phase) 

    /**
     * Get The ID of this lifecycle, for identification in the mojo
     * descriptor.
     */
    public String getId()
    {
        return this.id;
    } //-- String getId() 

    /**
     * Method getPhases
     */
    public java.util.List getPhases()
    {
        if ( this.phases == null )
        {
            this.phases = new java.util.ArrayList();
        }
        
        return this.phases;
    } //-- java.util.List getPhases() 

    /**
     * Method removePhase
     * 
     * @param phase
     */
    public void removePhase(Phase phase)
    {
        getPhases().remove( phase );
    } //-- void removePhase(Phase) 

    /**
     * Set The ID of this lifecycle, for identification in the mojo
     * descriptor.
     * 
     * @param id
     */
    public void setId(String id)
    {
        this.id = id;
    } //-- void setId(String) 

    /**
     * Set The phase mappings for this lifecycle.
     * 
     * @param phases
     */
    public void setPhases(java.util.List phases)
    {
        this.phases = phases;
    } //-- void setPhases(java.util.List) 


    private String modelEncoding = "UTF-8";

    public void setModelEncoding( String modelEncoding )
    {
        this.modelEncoding = modelEncoding;
    }

    public String getModelEncoding()
    {
        return modelEncoding;
    }}
